==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/it.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Notifiche di aggiornamento",
    "Could not start updater, please try the manual update" : "Impossibile avviare lo strumento di aggiornamento, prova l'aggiornamento manuale",
    "{version} is available. Get more information on how to update." : "{version} è disponibile. Ottieni ulteriori informazioni su come eseguire l'aggiornamento.",
    "Channel updated" : "Canale aggiornato",
    "Update to %1$s is available." : "Aggiornamento a %1$s disponibile.",
    "Update for %1$s to version %2$s is available." : "È disponibile l'aggiornamento di %1$s alla versione %2$s.",
    "Update for {app} to version %s is available." : "È disponibile l'aggiornamento di {app} alla versione %s.",
    "Update notification" : "Notifiche di aggiornamento",
    "A new version is available: %s" : "Una nuova versione è disponibile: %s",
    "Open updater" : "Apri strumento di aggiornamento",
    "Download now" : "Scarica ora",
    "Your version is up to date." : "La tua versione è aggiornata.",
    "Checked on %s" : "Controllato il %s",
    "Update channel:" : "Canale di aggiornamento:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Puoi aggiornare sempre a una nuova versione / canale sperimentale. Ma non puoi mai tornare a una versione precedente.",
    "Notify members of the following groups about available updates:" : "Notifica i membri dei seguenti gruppi sugli aggiornamenti disponibili:",
    "Only notification for app updates are available." : "Sono disponibili solo le notifiche per gli aggiornamenti delle applicazioni.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Il canale di aggiornamento selezionato rende obsolete le notifiche dedicate al server.",
    "The selected update channel does not support updates of the server." : "Il canale di aggiornamento selezionato non supporta gli aggiornamenti del server."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.3-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/it.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Notifiche di aggiornamento",
    "Could not start updater, please try the manual update" : "Impossibile avviare lo strumento di aggiornamento, prova l'aggiornamento manuale",
    "{version} is available. Get more information on how to update." : "{version} è disponibile. Ottieni ulteriori informazioni su come eseguire l'aggiornamento.",
    "Channel updated" : "Canale aggiornato",
    "The update server could not be reached since %d days to check for new updates." : "Il server degli aggiornamenti non è raggiungibile da %d giorni per controllare la presenza di nuovi aggiornamenti.",
    "Please check the Nextcloud and server log files for errors." : "Controlla i file di log di Nextcloud e del server alla ricerca di errori.",
    "Update to %1$s is available." : "Aggiornamento a %1$s disponibile.",
    "Update for %1$s to version %2$s is available." : "È disponibile l'aggiornamento di %1$s alla versione %2$s.",
    "Update for {app} to version %s is available." : "È disponibile l'aggiornamento di {app} alla versione %s.",
    "A new version is available: %s" : "Una nuova versione è disponibile: %s",
    "Open updater" : "Apri strumento di aggiornamento",
    "Download now" : "Scarica ora",
    "The update check is not yet finished. Please refresh the page." : "Il controllo degli aggiornamenti non è ancora terminato. Aggiorna la pagina.",
    "Your version is up to date." : "La tua versione è aggiornata.",
    "Checked on %s" : "Controllato il %s",
    "A non-default update server is in use to be checked for updates:" : "Stai utilizzando un server non predefinito per controllare gli aggiornamenti:",
    "Update channel:" : "Canale di aggiornamento:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Puoi aggiornare sempre a una nuova versione / canale sperimentale. Ma non puoi mai tornare a una versione precedente.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Nota che, dopo una nuova versione, potrebbe essere necessario del tempo prima che sia mostrato qui. Rilasciamo nel tempo nuove versioni ai nostri utenti e, a volte, saltiamo una versione, se troviamo dei problemi.",
    "Notify members of the following groups about available updates:" : "Notifica i membri dei seguenti gruppi sugli aggiornamenti disponibili:",
    "Only notification for app updates are available." : "Sono disponibili solo le notifiche per gli aggiornamenti delle applicazioni.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Il canale di aggiornamento selezionato rende obsolete le notifiche dedicate al server.",
    "The selected update channel does not support updates of the server." : "Il canale di aggiornamento selezionato non supporta gli aggiornamenti del server."
},
"nplurals=2; plural=(n != 1);");
